@@ -244,6 +244,90 @@ def update_sets(l):
     l['VARGS_OPS']       = frozenset(l['hasvargs'])
     l['STORE_OPS']       = frozenset(l['hasstore'])
 
+
+def extended_format_CALL_FUNCTION(opc, instructions):
+    """call_function_inst should be a "CALL_FUNCTION_KW" instruction. Look in
+    `instructions` to see if we can find a method name.  If not we'll
+    return None.
+
+    """
+    # From opcode description: argc indicates the total number of positional and keyword arguments.
+    # Sometimes the function name is in the stack arg positions back.
+    call_function_inst = instructions[0]
+    assert call_function_inst.opname == "CALL_FUNCTION"
+    argc = call_function_inst.arg
+    name_default, pos_args, = divmod(argc, 256)
+    function_pos = pos_args + name_default*2 + 1
+    assert len(instructions) >= function_pos + 1
+    for i, inst in enumerate(instructions[1:]):
+        if i + 1 == function_pos:
+            i += 1
+            break
+        if inst.is_jump_target:
+            i += 1
+            break
+        # Make sure we are in the same basic block
+        # and ... ?
+        opcode = inst.opcode
+        if inst.optype in ("nargs", "vargs"):
+            break
+        if inst.opname == "LOAD_ATTR" or inst.optype != "name":
+            function_pos += (opc.oppop[opcode] - opc.oppush[opcode]) + 1
+        if inst.opname in ("CALL_FUNCTION", "CALL_FUNCTION_KW"):
+            break
+        pass
+
+    s = ""
+    if i == function_pos:
+        if instructions[function_pos].opname in ("LOAD_CONST", "LOAD_GLOBAL",
+                                                 "LOAD_ATTR", "LOAD_NAME"):
+            s = resolved_attrs(instructions[function_pos:])
+            s += ": "
+            pass
+        pass
+    s += format_CALL_FUNCTION_pos_name_encoded(call_function_inst.arg)
+    return s
+
+def resolved_attrs(instructions):
+    resolved = []
+    for inst in instructions:
+        name = inst.argrepr
+        if name:
+            if name[0] == "'" and name[-1] == "'":
+                name = name[1:-1]
+        else:
+            name = ""
+        resolved.append(name)
+        if inst.opname != "LOAD_ATTR":
+            break
+    return ".".join(reversed(resolved))
+
+def extended_format_MAKE_FUNCTION_older(opc, instructions):
+    """make_function_inst should be a "MAKE_FUNCTION" or "MAKE_CLOSURE" instruction. TOS
+    should have the function or closure name.
+    """
+    # From opcode description: argc indicates the total number of positional and keyword arguments.
+    # Sometimes the function name is in the stack arg positions back.
+    assert len(instructions) >= 2
+    inst = instructions[0]
+    assert inst.opname in ("MAKE_FUNCTION", "MAKE_CLOSURE")
+    s = ""
+    code_inst = instructions[1]
+    if code_inst.opname == "LOAD_CONST" and hasattr(code_inst.argval, "co_name"):
+        s += "%s: " % code_inst.argval.co_name
+        pass
+    s += format_MAKE_FUNCTION_default_argc(inst.arg)
+    return s
+
+def extended_format_RETURN_VALUE(opc, instructions):
+    return_inst = instructions[0]
+    assert return_inst.opname == "RETURN_VALUE"
+    assert len(instructions) >= 1
+    if instructions[1].opname in ("LOAD_CONST", "LOAD_GLOBAL",
+                                  "LOAD_ATTR", "LOAD_NAME"):
+        return resolved_attrs(instructions[1:])
+    return None
+
 def format_extended_arg(arg):
     return str(arg * (1 << 16))
 
@@ -255,12 +339,17 @@ def format_CALL_FUNCTION_pos_name_encoded(argc):
     name_default, pos_args = divmod(argc, 256)
     return ("%d positional, %d named" % (pos_args, name_default))
 
+# After Python 3.2
 def format_MAKE_FUNCTION_arg(argc):
     name_and_annotate, pos_args = divmod(argc, 256)
     annotate_args, name_default = divmod(name_and_annotate, 256)
     return ("%d positional, %d name and default, %d annotations" %
             (pos_args, name_default, annotate_args))
 
+# Up to and including Python 3.2
+def format_MAKE_FUNCTION_default_argc(argc):
+    return ("%d default parameters" % argc)
+
 def opcode_check(l):
     """When the version of Python we are running happens
     to have the same opcode set as the opcode we are
