@@ -25,6 +25,8 @@ from xdis.cross_dis import findlabels
 
 import xdis.opcodes.opcode_13 as opcode_13
 from xdis.opcodes.base import (
+    extended_format_CALL_FUNCTION,
+    extended_format_RETURN_VALUE,
     init_opdata,
     finalize_opcodes,
     format_extended_arg,
@@ -44,4 +46,9 @@ opcode_arg_fmt = {"EXTENDED_ARG": format_extended_arg}
 
 finalize_opcodes(l)
 
+opcode_extended_fmt = {
+    "CALL_FUNCTION": extended_format_CALL_FUNCTION,
+    "RETURN_VALUE": extended_format_RETURN_VALUE,
+}
+
 findlinestarts = opcode_13.findlinestarts
