@@ -8,6 +8,8 @@ This is similar to the opcode portion in Python 2.2's dis.py library.
 import xdis.opcodes.opcode_2x as opcode_2x
 from xdis.opcodes.base import (
     def_op,
+    extended_format_MAKE_FUNCTION_older,
+    extended_format_RETURN_VALUE,
     init_opdata,
     finalize_opcodes,
     format_extended_arg,
@@ -27,6 +29,13 @@ def_op(l, "SET_LINENO", 127, 0, 0)
 update_pj2(globals(), l)
 
 
-opcode_arg_fmt = {"EXTENDED_ARG": format_extended_arg}
-
 finalize_opcodes(l)
+
+opcode_arg_fmt = {
+    "EXTENDED_ARG": format_extended_arg
+}
+
+opcode_extended_fmt = {
+    "MAKE_FUNCTION": extended_format_MAKE_FUNCTION_older,
+    "RETURN_VALUE": extended_format_RETURN_VALUE,
+}
