@@ -22,6 +22,7 @@ of stack usage.
 
 from xdis.opcodes.base import(
     def_op,
+    extended_format_RETURN_VALUE,
     finalize_opcodes,
     init_opdata, nargs_op,
     jrel_op,
@@ -29,6 +30,7 @@ from xdis.opcodes.base import(
     update_pj3
     )
 
+from xdis.opcodes.opcode_33 import extended_format_MAKE_FUNCTION
 import xdis.opcodes.opcode_36 as opcode_36
 
 version = 3.7
@@ -97,7 +99,7 @@ jrel_op(l, "SETUP_ASYNC_WITH",   154,  0,  5)
 name_op(l, "LOAD_METHOD", 160, 0, 1)
 nargs_op(l, "CALL_METHOD", 161, -2, 1)
 
-format_MAKE_FUNCTION_arg = opcode_36.format_MAKE_FUNCTION_arg
+format_MAKE_FUNCTION_flags = opcode_36.format_MAKE_FUNCTION_flags
 format_value_flags = opcode_36.format_value_flags
 
 opcode_arg_fmt = {
@@ -106,11 +108,18 @@ opcode_arg_fmt = {
     "CALL_FUNCTION_KW": opcode_36.format_CALL_FUNCTION_KW,
     "CALL_FUNCTION_EX": opcode_36.format_CALL_FUNCTION_EX,
     "CALL_METHOD": opcode_36.format_CALL_FUNCTION,
-    "MAKE_FUNCTION": format_MAKE_FUNCTION_arg,
+    "MAKE_FUNCTION": format_MAKE_FUNCTION_flags,
     "FORMAT_VALUE": format_value_flags,
     "EXTENDED_ARG": opcode_36.format_extended_arg36
 }
 
+opcode_extended_fmt = {
+    "CALL_FUNCTION": opcode_36.extended_format_CALL_FUNCTION,
+    "CALL_METHOD": opcode_36.extended_format_CALL_METHOD,
+    "MAKE_FUNCTION": extended_format_MAKE_FUNCTION,
+    "RETURN_VALUE": extended_format_RETURN_VALUE,
+}
+
 update_pj3(globals(), l)
 
 finalize_opcodes(l)
